#!/usr/bin/env python
# -*- coding: utf-8  -*-
################################################################################
#
#  Rattail -- Retail Software Framework
#  Copyright © 2010-2012 Lance Edgar
#
#  This file is part of Rattail.
#
#  Rattail is free software: you can redistribute it and/or modify it under the
#  terms of the GNU Affero General Public License as published by the Free
#  Software Foundation, either version 3 of the License, or (at your option)
#  any later version.
#
#  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
#  more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################

"""
``rattail.django.rattail.admin`` -- Admin Interface
"""

from django.contrib import admin

from rattail.django.rattail.models import *


class ModelAdmin(admin.ModelAdmin):
    """
    Base admin manager for all Rattail models.
    """

    def get_form(self, request, obj=None, **kwargs):
        kwargs.setdefault('exclude', ('uuid',))
        form = super(ModelAdmin, self).get_form(request, obj, **kwargs)
        return form


class StoreContactInfoInline(admin.TabularInline):
    exclude = ('uuid', 'parent_type')
    extra = 0

class StorePhoneNumberInline(StoreContactInfoInline):
    model = StorePhoneNumber
    verbose_name_plural = "Phone Numbers"

class StoreEmailAddressInline(StoreContactInfoInline):
    model = StoreEmailAddress
    verbose_name_plural = "Email Addresses"

class StoreAdmin(ModelAdmin):
    inlines = [StorePhoneNumberInline, StoreEmailAddressInline]

admin.site.register(Store, StoreAdmin)


admin.site.register(Department, ModelAdmin)


admin.site.register(Subdepartment, ModelAdmin)


admin.site.register(Category, ModelAdmin)


admin.site.register(Brand, ModelAdmin)


class ProductPriceInline(admin.TabularInline):
    model = ProductPrice
    verbose_name_plural = "Prices"
    exclude = ('uuid',)
    extra = 0

class ProductAdmin(ModelAdmin):
    inlines = [ProductPriceInline]

admin.site.register(Product, ProductAdmin)
